pub struct TelegramLink {
pub telegram_id: Option<i64>,
pub user_id: String,
pub username: Option<String>,
pub linked_at: DateTime<Utc>,
}Expand description
A linked Telegram account.
A link can be created with just a username (telegram_id filled when the user first messages the bot) or with a numeric Telegram ID directly.
Fields
telegram_id: Option<i64>user_id: Stringusername: Option<String>linked_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for TelegramLink
impl Clone for TelegramLink
Sourcefn clone(&self) -> TelegramLink
fn clone(&self) -> TelegramLink
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TelegramLink
impl Debug for TelegramLink
Sourceimpl<'de> Deserialize<'de> for TelegramLink
impl<'de> Deserialize<'de> for TelegramLink
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more